@@ -10,6 +10,8 @@ module Debian.Debianize.BuildDependencies
 import Control.Applicative ((<$>))
 #endif
 import Control.Lens
+import Control.Monad ((>=>))
+import Control.Monad.IO.Class (liftIO)
 import Control.Monad.State (MonadState(get))
 import Control.Monad.Trans (MonadIO)
 import Data.Char (isSpace, toLower)
@@ -20,7 +22,7 @@ import Data.Maybe (catMaybes, fromMaybe, isJust, isNothing, listToMaybe, mapMayb
 import Data.Monoid ((<>))
 import Data.Set as Set (empty, fold, fromList, map, member, Set, singleton, toList, union)
 import Debian.Debianize.Prelude
-import Debian.Debianize.BasicInfo (buildEnv, compilerFlavor, EnvSet(dependOS))
+import Debian.Debianize.BasicInfo (compilerFlavor)
 import Debian.Debianize.Bundled (builtIn)
 import qualified Debian.Debianize.DebInfo as D
 import Debian.Debianize.DebianName (mkPkgName, mkPkgName')
@@ -87,8 +89,7 @@ allBuildDepends buildInfos =
       (mergeCabalDependencies $ concatMap Cabal.targetBuildDepends buildInfos)
       (mergeCabalDependencies $ mapMaybe convertLegacy $ concatMap buildTools buildInfos)
       (mergeCabalDependencies $ mapMaybe convertPkgconfig $  concatMap pkgconfigDepends buildInfos)
-      (concatMap extraLibs buildInfos) >>=
-    return {- . List.filter (not . selfDependency (Cabal.package pkgDesc)) -}
+      (concatMap extraLibs buildInfos)
     where
 #if MIN_VERSION_Cabal(2,0,0)
       convertLegacy :: LegacyExeDependency -> Maybe Dependency
@@ -108,9 +109,9 @@ allBuildDepends buildInfos =
                             [ExtraLibs (fixDeps atoms extraLibs')]
 
       fixDeps :: CabalInfo -> [String] -> Relations
-      fixDeps atoms xs =
+      fixDeps atoms =
           concatMap (\ cab -> fromMaybe [[D.Rel (D.BinPkgName ("lib" ++ List.map toLower cab ++ "-dev")) Nothing Nothing]]
-                                        (Map.lookup cab (view (A.debInfo . D.extraLibMap) atoms))) xs
+                                        (Map.lookup cab (view (A.debInfo . D.extraLibMap) atoms)))
 
 -- | Take the intersection of all the dependencies on a given package name
 mergeCabalDependencies :: [Dependency] -> [Dependency]
@@ -155,15 +156,14 @@ debianBuildDeps pkgDesc =
             ]
 
        bDeps <- use (A.debInfo . D.control . S.buildDepends)
-       official <- use (A.debInfo . D.official)
        compat <- use (A.debInfo . D.compat)
-       let ghcdev = compilerPackageName hflavor B.Development
+       ghcdev <- liftIO $ compilerPackageName hflavor B.Development
+       ghcprof <- liftIO $ compilerPackageName hflavor B.Profiling
        let ghcrel = if member GHC hcs then maybe [] ((: []) . anyrel') ghcdev else []
-       let ghcprof = compilerPackageName hflavor B.Profiling
        let ghcrelprof = if prof then maybe [] ((: []) . anyrel') ghcprof else []
        let xs = nub $ [maybe [] (\ n -> [D.Rel (D.BinPkgName "debhelper") (Just (D.GRE (parseDebianVersion' (show n)))) Nothing]) compat,
                        [D.Rel (D.BinPkgName "haskell-devscripts-minimal") Nothing Nothing,
-                        D.Rel (D.BinPkgName "haskell-devscripts") (Just $ D.GRE $ parseDebianVersion' $ if official then "0.9" else "0.8" :: String) Nothing],
+                        D.Rel (D.BinPkgName "haskell-devscripts") (Just $ D.GRE $ parseDebianVersion' ("0.13" :: String)) Nothing],
                        anyrel "cdbs"] ++
                       (ghcrel ++ ghcrelprof) ++
 {-
@@ -209,7 +209,7 @@ debianBuildDepsIndep pkgDesc =
        bDeps <- use (A.debInfo . D.control . S.buildDependsIndep)
        libDeps <- allBuildDepends (maybe [] (return . libBuildInfo) (Cabal.library pkgDesc))
        cDeps <- mapM docDependencies libDeps
-       let ghcdoc = compilerPackageName hc B.Documentation
+       ghcdoc <- liftIO $ compilerPackageName hc B.Documentation
        let hcdocdep = if doc && member GHC hcs then maybe [] ((: []) . anyrel') ghcdoc else []
        let xs = nub $ if doc && isJust (Cabal.library pkgDesc)
                       then hcdocdep ++ bDeps ++ concat cDeps
@@ -240,7 +240,7 @@ buildDependencies _ dep@(ExtraLibs _) =
 buildDependencies _ dep =
     case unboxDependency dep of
       Just (Dependency _name _ranges) ->
-          do mp <- get >>= return . view (A.debInfo . D.execMap)
+          do mp <- view (A.debInfo . D.execMap) <$> get
              return $ concat $ adapt mp dep
       Nothing ->
           return []
@@ -305,13 +305,13 @@ dependencies hc typ name cabalRange omitProfVersionDeps =
           case isNoVersion range''' of
             True -> return Nothing
             False ->
-                foldVersionRange'
+                Just <$> foldVersionRange'
                           (return $ Rel' (D.Rel dname Nothing Nothing))
-                          (\ v -> debianVersion' name v >>= \ dv -> return $ Rel' (D.Rel dname (Just (D.EEQ dv)) Nothing))
-                          (\ v -> debianVersion' name v >>= \ dv -> return $ Rel' (D.Rel dname (Just (D.SGR dv)) Nothing))
-                          (\ v -> debianVersion' name v >>= \ dv -> return $ Rel' (D.Rel dname (Just (D.SLT dv)) Nothing))
-                          (\ v -> debianVersion' name v >>= \ dv -> return $ Rel' (D.Rel dname (Just (D.GRE dv)) Nothing))
-                          (\ v -> debianVersion' name v >>= \ dv -> return $ Rel' (D.Rel dname (Just (D.LTE dv)) Nothing))
+                          (debianVersion' name >=> \ dv -> return $ Rel' (D.Rel dname (Just (D.EEQ dv)) Nothing))
+                          (debianVersion' name >=> \ dv -> return $ Rel' (D.Rel dname (Just (D.SGR dv)) Nothing))
+                          (debianVersion' name >=> \ dv -> return $ Rel' (D.Rel dname (Just (D.SLT dv)) Nothing))
+                          (debianVersion' name >=> \ dv -> return $ Rel' (D.Rel dname (Just (D.GRE dv)) Nothing))
+                          (debianVersion' name >=> \ dv -> return $ Rel' (D.Rel dname (Just (D.LTE dv)) Nothing))
 #if MIN_VERSION_Cabal(2,0,0)
                           (\ x y -> debianVersion' name x >>= \ dvx ->
                                     debianVersion' name y >>= \ dvy ->
@@ -325,7 +325,7 @@ dependencies hc typ name cabalRange omitProfVersionDeps =
                           (\ x y -> x >>= \ x' -> y >>= \ y' -> return $ Or [x', y'])
                           (\ x y -> x >>= \ x' -> y >>= \ y' -> return $ And [x', y'])
                           id
-                          range''' >>= return . Just
+                          range'''
           where
             -- Choose the simpler of the two
             range''' = canon (simpler range' range'')
@@ -368,21 +368,20 @@ doBundled :: MonadIO m =>
           -> [D.Relation]
           -> CabalT m [D.Relation]
 doBundled typ name hc rels = do
-  let hcname = compilerPackageName hc typ
-  mapM (doRel hcname) rels >>= return . concat
+  hcname <- liftIO $ compilerPackageName hc typ
+  concat <$> mapM (doRel hcname) rels
     where
       -- If a library is built into the compiler, this is the debian
       -- package name the compiler will conflict with.
-      doRel :: Monad m => Maybe BinPkgName -> D.Relation -> CabalT m [D.Relation]
+      doRel :: MonadIO m => Maybe BinPkgName -> D.Relation -> CabalT m [D.Relation]
       doRel hcname rel@(D.Rel dname req _) = do
         let comp = maybe [] (\x -> [D.Rel x Nothing Nothing]) hcname
         -- gver <- use ghcVersion
-        root <- use (A.debInfo . D.flags . buildEnv) >>= return . dependOS
         -- Look at what version of the package is provided by the compiler.
         atoms <- get
         -- What version of this package (if any) does the compiler provide?
-        let relInfo = builtIn hc root
-            pver = listToMaybe $ fmap (debianVersion'' atoms) (filter ((== name) . pkgName) relInfo)
+        relInfo <- liftIO $ builtIn hc
+        let pver = listToMaybe $ fmap (debianVersion'' atoms) (filter ((== name) . pkgName) relInfo)
         -- The name this library would have if it was in the compiler conflicts list.
         let naiveDebianName = mkPkgName hc name typ
         -- The compiler should appear in the build dependency
@@ -391,12 +390,12 @@ doBundled typ name hc rels = do
         -- library (which, if pver is Nothing, will certainly
         -- result in an error which needs to be corrected in
         -- the packaging.)
-        let compilerDependency = if isJust pver && (checkVersionReq req pver || (dname == naiveDebianName && conflictsWithHC naiveDebianName)) then comp else []
+        let compilerDependency = if isJust pver && (checkVersionReq req pver || dname == naiveDebianName) then comp else []
         -- The library package can satisfy the dependency if
         -- the compiler doesn't provide a version, or if the
         -- compiler doesn't conflict with the package's
         -- debian name.
-        let libraryDependency = if isNothing pver || dname /= naiveDebianName || not (conflictsWithHC naiveDebianName) then [rel] else []
+        let libraryDependency = if isNothing pver || dname /= naiveDebianName then [rel] else []
         -- Is the version number in the library dependency newer than
         -- the compiler version?  If so it should appear to its left,
         -- otherwise to its right.
@@ -405,28 +404,6 @@ doBundled typ name hc rels = do
                    Just (D.LTE lver) | Just lver < pver -> compilerDependency ++ libraryDependency
                    Just (D.EEQ lver) | Just lver < pver -> compilerDependency ++ libraryDependency
                    _ -> libraryDependency ++ compilerDependency
-      -- FIXME: we are assuming here that ghc conflicts with all the
-      -- library packages it provides but it no longer conflicts with
-      -- libghc-cabal-dev.  We can now check these conflicts using the
-      -- new functions in Bundled.
-      conflictsWithHC (BinPkgName "libghc-cabal-dev") = False
-      conflictsWithHC (BinPkgName "libghc-cabal-prof") = False
-      conflictsWithHC (BinPkgName "libghc-cabal-doc") = False
-      conflictsWithHC _ = True
-
-{-
-doBundled :: Monad m =>
-             B.PackageType  -- Documentation, Profiling, Development...
-          -> PackageName    -- Cabal package name
-          -> [D.Relation]   -- Original set of debian dependencies
-          -> CabalT m [D.Relation] -- Modified debian dependencies accounting for the packages the compiler provides
-doBundled hc typ name rels =
-    concat <$> mapM doRel rels
-    where
-      doRel :: Monad m => D.Relation -> CabalT m [D.Relation]
-      doRel rel@(D.Rel dname req _) = do
-        hc <- use
--}
 
 -- Convert a cabal version to a debian version, adding an epoch number if requested
 debianVersion' :: Monad m => PackageName -> Version -> CabalT m DebianVersion
@@ -446,7 +423,7 @@ convert' = List.map (List.map unRel . unOr) . unAnd . canonical
 canonical :: Rels a -> Rels a
 canonical (Rel' rel) = And [Or [Rel' rel]]
 canonical (And rels) = And $ concatMap (unAnd . canonical) rels
-canonical (Or rels) = And . List.map Or $ sequence $ List.map (concat . List.map unOr . unAnd . canonical) $ rels
+canonical (Or rels) = And . List.map Or $ mapM (concatMap unOr . unAnd . canonical) rels
 
 filterMissing :: Monad m => [[Relation]] -> CabalT m [[Relation]]
 filterMissing rels =
