@@ -28,7 +28,6 @@ import Data.Map as Map (delete, elems, insertWith, lookup, Map, toList)
 import Data.Maybe (fromMaybe, isJust, fromJust)
 import Data.Monoid ((<>))
 import Data.Set as Set (difference, filter, fold, fromList, insert, map, null, Set, singleton, toList, union, unions)
-import Data.Set.Extra as Set (mapM_)
 import Data.Text as Text (intercalate, pack, Text, unlines, unpack)
 import Debian.Changes (ChangeLog(..), ChangeLogEntry(..))
 import Debian.Codename (parseCodename)
@@ -478,7 +477,7 @@ officialSettings = do
 
         let packagesURI = "https://salsa.debian.org/haskell-team/DHG_packages/tree/master/p/" <> pack src
         zoom D.control $ do
-           S.standardsVersion .?= Just (parseStandardsVersion "4.1.1")
+           S.standardsVersion .?= Just (parseStandardsVersion "4.4.0")
 #if MIN_VERSION_Cabal(2,0,0)
            S.homepage .?= Just ("https://hackage.haskell.org/package/" <> pack (unPackageName cabal))
 #else
@@ -530,8 +529,7 @@ binaryPackageRelations b typ = zoom A.debInfo $ do
     B.breaks     .= []
     B.builtUsing .= []
 
-    unless (typ == B.Documentation) $ do
-      B.provides %= (anyrel "${haskell:Provides}" :)
+    unless (typ == B.Documentation) $ B.provides %= (anyrel "${haskell:Provides}" :)
 
 -- | Add the library paragraphs for a particular compiler flavor.
 librarySpecs :: (Monad m) => PackageDescription -> CompilerFlavor -> CabalT m ()
@@ -641,13 +639,13 @@ makeUtilsPackage pkgDesc hc =
          (A.debInfo . D.binaryDebDescription b . B.binarySection) .?= Just (MainSection "misc")
          binaryPackageRelations b B.Utilities
        -- Add the unassigned files to the utils packages
-       Set.mapM_ (\ (foo, bar) -> (A.debInfo . D.atomSet) %= (Set.insert $ D.InstallData b foo bar)) utilsDataMissing
-       Set.mapM_ (\ name -> (A.debInfo . D.atomSet) %= (Set.insert $ D.InstallCabalExec b name "usr/bin")) utilsExecMissing
+       mapM_ (\ (foo, bar) -> (A.debInfo . D.atomSet) %= (Set.insert $ D.InstallData b foo bar)) utilsDataMissing
+       mapM_ (\ name -> (A.debInfo . D.atomSet) %= (Set.insert $ D.InstallCabalExec b name "usr/bin")) utilsExecMissing
     where
       ename i =
           case D.sourceDir i of
-            (Nothing) -> D.execName i
-            (Just s) ->  s </> D.execName i
+            Nothing -> D.execName i
+            Just s ->  s </> D.execName i
 
 expandAtoms :: Monad m => CabalT m () -> CabalT m ()
 expandAtoms goodies =
@@ -694,7 +692,7 @@ expandAtoms goodies =
       expandInstallCabalExecs :: Monad m => FilePath -> CabalT m ()
       expandInstallCabalExecs builddir = do
         hc <- use (A.debInfo . D.flags . compilerFlavor)
-        use (A.debInfo . D.atomSet) >>= Set.mapM_ (doAtom hc)
+        use (A.debInfo . D.atomSet) >>= mapM_ (doAtom hc)
           where
             doAtom :: Monad m => CompilerFlavor -> D.Atom -> CabalT m ()
             doAtom GHC (D.InstallCabalExec b name dest) = (A.debInfo . D.atomSet) %= (Set.insert $ D.Install b (builddir </> name </> name) dest)
@@ -714,7 +712,7 @@ expandAtoms goodies =
       expandInstallCabalExecTo :: Monad m => FilePath -> CabalT m ()
       expandInstallCabalExecTo builddir = do
         hc <- use (A.debInfo . D.flags . compilerFlavor)
-        use (A.debInfo . D.atomSet) >>= Set.mapM_ (doAtom hc)
+        use (A.debInfo . D.atomSet) >>= mapM_ (doAtom hc)
           where
             doAtom :: Monad m => CompilerFlavor -> D.Atom -> CabalT m ()
             doAtom GHC (D.InstallCabalExecTo b name dest) =
@@ -774,12 +772,13 @@ finalizeRules :: (MonadIO m) => CabalT m ()
 finalizeRules =
     do DebBase b <- debianNameBase
        hc <- use (A.debInfo . D.flags . compilerFlavor)
-       let BinPkgName hcdeb = maybe (error "No compiler package") id (compilerPackageName hc B.Development)
+       cpn <- liftIO $ compilerPackageName hc B.Development
+       let BinPkgName hcdeb = fromMaybe (error "No compiler package") cpn
        (A.debInfo . D.rulesHead) .?= Just "#!/usr/bin/make -f"
        (A.debInfo . D.rulesSettings) %= (++ ["DEB_CABAL_PACKAGE = " <> pack b])
        (A.debInfo . D.rulesSettings) %= (++ ["DEB_DEFAULT_COMPILER = " <> pack hcdeb])
-       flags <- (flagString . Set.toList) <$> use (A.debInfo . D.flags . cabalFlagAssignments)
-       unless (List.null flags) ((A.debInfo . D.rulesSettings) %= (++ ["DEB_SETUP_GHC6_CONFIGURE_ARGS = " <> pack flags]))
+       flags <- flagString . Set.toList <$> use (A.debInfo . D.flags . cabalFlagAssignments)
+       unless (List.null flags) ((A.debInfo . D.rulesSettings) %= (++ ["DEB_SETUP_GHC_CONFIGURE_ARGS = " <> pack flags]))
        (A.debInfo . D.rulesIncludes) %= (++ ["include /usr/share/cdbs/1/rules/debhelper.mk",
                                              "include /usr/share/cdbs/1/class/hlibrary.mk"])
 
@@ -809,7 +808,7 @@ flagList = List.map tagWithValue . words
 
 flagString :: [(FlagName, Bool)] -> String
 #if MIN_VERSION_Cabal(2,0,0)
-flagString = List.intercalate " " . List.map (\ (s, sense) -> "-f" ++ (if sense then "" else "-") ++ unFlagName s)
+flagString = unwords . List.map (\ (s, sense) -> "-f" ++ (if sense then "" else "-") ++ unFlagName s)
 #else
-flagString = List.intercalate " " . List.map (\ (FlagName s, sense) -> "-f" ++ (if sense then "" else "-") ++ s)
+flagString = unwords . List.map (\ (FlagName s, sense) -> "-f" ++ (if sense then "" else "-") ++ s)
 #endif
