@@ -120,14 +120,10 @@ debianPackageVersion name =
       parseDebianVersion'' "" = Nothing
       parseDebianVersion'' s = Just (parseDebianVersion' s)
 
--- | The version number of the installed debhelper package is the
--- highest acceptable value for compat in a debian/control file.  If
--- the package doesn't explicitly set an (acceptable) compat value we
--- can use the value returned by this function, assuming debhelper is
--- installed.
+-- | With the current state of CDBS, anything above 10 breaks, so
+-- for now we force this to 10.
 getDebhelperCompatLevel :: IO (Maybe Int)
-getDebhelperCompatLevel =
-    debianPackageVersion "debhelper" >>= return . fmap (min 9 . read . takeWhile (/= '.') . version)
+getDebhelperCompatLevel = return (Just 10)
 
 data StandardsVersion = StandardsVersion Int Int Int (Maybe Int) deriving (Eq, Ord, Show, Data, Typeable)
 
@@ -367,9 +363,9 @@ instance Pretty License where
     pretty Public_Domain = text "public-domain"
     pretty Apache = text "Apache"
     pretty Artistic = text "Artistic"
-    pretty BSD_2_Clause = text "BSD2"
-    pretty BSD_3_Clause = text "BSD3"
-    pretty BSD_4_Clause = text "BSD4"
+    pretty BSD_2_Clause = text "BSD-2-clause"
+    pretty BSD_3_Clause = text "BSD-3-clause"
+    pretty BSD_4_Clause = text "BSD-4-clause"
     pretty ISC = text "ISC"
     pretty CC_BY = text "CC-BY"
     pretty CC_BY_SA = text "CC-BY-SA"
